.. _contributors-team-meetings-roadmap-calendar:

Team Meetings, Road Map and Calendar
====================================

Many of the lead Jupyter Server developers meet weekly over Zoom. These meetings are open to everyone.

To see when the next meeting is happening and how to attend, watch this Github issue:

https://github.com/jupyter-server/team-compass/issues/15

Meeting Notes
-------------

- `2022 <https://github.com/jupyter-server/team-compass/issues/15>`_
- `2021 <https://github.com/jupyter-server/team-compass/issues/4>`_
- `2019-2020 <https://github.com/jupyter-server/team-compass/issues/1>`_

Roadmap
-------

Also check out Jupyter Server's roadmap where we track future plans for Jupyter Server:

`Jupyter Server 2.0 Discussion <https://github.com/jupyter-server/team-compass/issues/24>`_

`Archived roadmap <https://github.com/jupyter/jupyter_server/issues/127>`_

Jupyter Calendar
----------------

.. raw:: html

    <iframe src="https://calendar.google.com/calendar/embed?height=600&amp;wkst=1&amp;bgcolor=%23ffffff&amp;ctz=America%2FLos_Angeles&amp;src=bTNoZWs2OWRhZzczODF1bXQ4a2NqZDc1dTRAZ3JvdXAuY2FsZW5kYXIuZ29vZ2xlLmNvbQ&amp;color=%23F6BF26" style="border:solid 1px #777" width="700" height="500" frameborder="0" scrolling="no"></iframe>
